@@ -1,9 +1,9 @@
 package SQL::Translator;
 
-use Moo 1.000003;
+use Moo;
 our ( $DEFAULT_SUB, $DEBUG, $ERROR );
 
-our $VERSION  = '0.11013_02';
+our $VERSION  = '0.11013_03';
 $DEBUG    = 0 unless defined $DEBUG;
 $ERROR    = "";
 
